OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Ustvarite novo zbirko {board}",
    "{user} has created a new board {board}" : "{user} ustvari novo zbirko {board}",
    "You have deleted the board {board}" : "Izbrišete zbirko {board}",
    "{user} has deleted the board {board}" : "{user} izbriše zbirko {board}",
    "You have restored the board {board}" : "Obnovite izbrisano zbirko {board}",
    "{user} has restored the board {board}" : "{user} obnovi izbrisano zbirko {board}",
    "You have shared the board {board} with {acl}" : "Omogočite souporabo zbirke {board} z uporabnikom {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} omogoči souporabo zbirke {board} z uporabnikom {acl}",
    "You have removed {acl} from the board {board}" : "Odstranite uporabnika {acl} z zbirke {board}",
    "{user} has removed {acl} from the board {board}" : "{user} odstrani uporabnika {acl} z zbirke {board}",
    "You have renamed the board {before} to {board}" : "Zbirko {before} preimenujete v {board}",
    "{user} has renamed the board {before} to {board}" : "{user} preimenuje zbirko {before} v {board}",
    "You have archived the board {board}" : "Arhivirate zbirko {board}",
    "{user} has archived the board {before}" : "{user} arhivira zbirko {board}",
    "You have unarchived the board {board}" : "Povrnete zbirko {board} iz arhiva",
    "{user} has unarchived the board {before}" : "{user} povrne zbirko {board} iz arhiva",
    "You have created a new list {stack} on board {board}" : "Ustvarite nov seznam nalog {stack} v zbirki {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} ustvari v zbirki {board} nov seznam nalog {stack}",
    "You have renamed list {before} to {stack} on board {board}" : "Preimenujete seznam nalog v zbirki {board} iz {before} v {stack}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} je preimenoval seznam nalog v zbirki {board} iz {before} v {stack}",
    "You have deleted list {stack} on board {board}" : "Izbrišete seznam nalog {stack} v zbirki {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} izbriše seznam nalog {stack} v zbirki {board}",
    "You have created card {card} in list {stack} on board {board}" : "Ustvarite nalogo {card} v seznamu nalog {stack} zbirke {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} ustvari nalogo {card} v seznamu nalog {stack} zbirke {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Izbrišete nalogo {card} v seznamu nalog {stack} zbirke {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} izbriše nalogo {card} v seznamu nalog {stack} zbirke {board}",
    "You have renamed the card {before} to {card}" : "Preimenujete nalogo {before} v {card}",
    "{user} has renamed the card {before} to {card}" : "{user} preimenuje nalogo {before} v {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Dodate opis k nalogi {card} v seznamu nalog {stack} zbirke {board}.",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} doda opis k nalogi {card} v seznamu nalog {stack} zbirke {board}.",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Posodobite opis naloge {card} v seznamu nalog {stack} zbirke {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} posodobi opis naloge {card} v seznamu nalog {stack} zbirke {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Arhivirate nalogo {card} v seznamu nalog {stack} zbirke {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} arhivira nalogo {card} v seznamu nalog {stack} zbirke {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Iz arhiva povrnete nalogo {card} v seznamu nalog {stack} zbirke {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} iz arhiva povrne nalogo {card} v seznamu nalog {stack} zbirke {board}",
    "You have removed the due date of card {card}" : "Odstranite datum preteka z naloge {card}",
    "{user} has removed the due date of card {card}" : "{user} odstrani datum preteka z naloge {card}",
    "You have set the due date of card {card} to {after}" : "Nastavite datum preteka naloge {card} na {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} nastavi datum preteka naloge {card} na {after}",
    "You have updated the due date of card {card} to {after}" : "Posodobite datum preteka naloge {card} na {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} posodobi datum preteka naloge {card} na {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Dodate oznako {label} k nalogi {card} seznama nalog {stack} v zbirki {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} doda oznako {label} k nalogi {card} seznama nalog {stack} v zbirki {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Odstranite oznako {label} z naloge {card} seznama nalog {stack} v zbirki {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} odstrani oznako {label} z naloge {card} seznama nalog {stack} v zbirki {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Dodelite nalogo {card} v zbirki {board} → {assigneduser}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} dodeli nalogo {card} v zbirki {board} → {assigneduser}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Odvzamete nalogo {card} v zbirki {board} ✕ {assigneduser}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} odvzame nalogo {card} v zbirki {board} ✕ {assigneduser}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Premaknete nalogo {card} iz seznama nalog {stackBefore} v {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} premakne nalogo {card} iz seznama nalog {stackBefore} v {stack}",
    "You have added the attachment {attachment} to card {card}" : "Dodate prilogo {attachment} k nalogi {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} doda prilogo {attachment} k nalogi {card}",
    "You have updated the attachment {attachment} on card {card}" : "Posodobite prilogo {attachment} v nalogi {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} posodobi prilogo {attachment} v nalogi {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Izbišete prilogo {attachment} v nalogi {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} izbriše prilogo {attachment} iz naloge {card}",
    "You have restored the attachment {attachment} to card {card}" : "Obnovite prilogo {attachment} k nalogi {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} obnovi prilogo {attachment} naloge {card}",
    "You have commented on card {card}" : "Vpišete opombo k nalogi {card}",
    "{user} has commented on card {card}" : "{user} vpiše opombo k nalogi {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Spremenjen je<strong>opis ene izmed nalog</strong> v programu Deck",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Spremembe v programu <strong>Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "Nalogi je dodana nova <strong>opomba</strong>",
    "Personal" : "Osebno",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Nalogo »%s« na »%s« vam dodeli %s.",
    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} vam dodeli nalogo »%s« na »%s«.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Naloga »%s« na »%s« je dosegla datum preteka.",
    "%s has mentioned you in a comment on \"%s\"." : "%s vas omeni v opombi na »%s«.",
    "{user} has mentioned you in a comment on \"%s\"." : "{user} vas omeni v opombi na »%s«.",
    "The board \"%s\" has been shared with you by %s." : "Zborko »%s« vam dodeli %s.",
    "{user} has shared the board %s with you." : "{user} vam omogoča souporabo zbirke %s.",
    "No data was provided to create an attachment." : "Ni podanih podatkov za ustvarjanje priloge.",
    "Finished" : "Končano",
    "To review" : "Za pregled",
    "Action needed" : "Čaka na odziv",
    "Later" : "Kasneje",
    "copy" : "kopija",
    "To do" : "Prihajajoče naloge",
    "Doing" : "Naloge v teku",
    "Done" : "Končane naloge",
    "Example Task 3" : "Primer naloge 3",
    "Example Task 2" : "Primer naloge 2",
    "Example Task 1" : "Primer naloge 1",
    "The file was uploaded" : "Datoteka je uspešno poslana.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega določilo največje dovoljene velikosti v datoteki php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki je določena kot omejitev MAX_FILE_SIZE v zapisu HTML.",
    "The file was only partially uploaded" : "Datoteka ni bila poslana v celoti",
    "No file was uploaded" : "Datoteka ni bila poslana",
    "Missing a temporary folder" : "Manjka začasna mapa",
    "Could not write file to disk" : "Ni mogoče zapisati datoteke na disk",
    "A PHP extension stopped the file upload" : "Razširitev PHP onemogoča pošiljanje datoteke",
    "No file uploaded or file size exceeds maximum of %s" : "Ali ni poslane datoteke ali pa velikost datoteke presega omejitev %s",
    "Personal planning and team project organization" : "Osebno načrtovanje nalog in organizacija skupinskih projektov",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Program Deck je orodje za osebno načrtovanje in projektno delo v slogu kanban, ki se izvrstno vključuje v okolje Nextcloud.\n\nOrodje omogoča:\n- 📥 dodajanje in urejanje nalog\n- 📄 zapis dodatnih opomb v zapisu markdown\n- 🔖 dodeljevanje oznak za lažje urejanje in iskanje\n- 👥 souporabo v skupini, s prijatelji ali družino\n- 📎 pripenjanje in vstavljanje datotek v opise\n- 💬 opombe k posamezni nalogi\n- ⚡ sledenje spremembam in dejavnosti\n- 🚀 Organizaciji projekta",
    "Card details" : "Podrobnosti naloge",
    "Add board" : "Dodaj zbirko",
    "Select the board to link to a project" : "Izberite zbirko za povezavo s projektom",
    "Search by board title" : "Išči po imenu zbirke",
    "Select board" : "Izbor zbirke",
    "Select the card to link to a project" : "Izbor naloge za povezavo do projekta",
    "Select a board" : "Izbor zbirke",
    "Select a card" : "Izbor naloge",
    "Link to card" : "Poveži nalogo",
    "Cancel" : "Prekliči",
    "File already exists" : "Datoteka s tem imenom že obstaja.",
    "A file with the name {filename} already exists." : "Datoteka z imenom {filename} že obstaja.",
    "Do you want to overwrite it?" : "Ali želite predmet prepisati?",
    "Overwrite file" : "Prepiši datoteko",
    "Keep existing file" : "Ohrani obstoječe datoteke",
    "This board is read only" : "Zbirka je označena le za branje",
    "Drop your files to upload" : "Spustite datoteke za pošiljanje v oblak",
    "Archived cards" : "Arhivirane naloge",
    "Add list" : "Dodaj seznam",
    "List name" : "Ime seznama",
    "Apply filter" : "Uveljavi filter",
    "Filter by tag" : "Filtriraj po oznaki",
    "Filter by assigned user" : "Filtriraj po dodeljenem uporabniku",
    "Unassigned" : "Nedodeljeno",
    "Filter by due date" : "Filtriraj po datumu preteka",
    "Overdue" : "Preteklo",
    "Next 24 hours" : "Naslednjih 24 ur",
    "Next 7 days" : "Naslednjih 7 dni",
    "Next 30 days" : "Naslednjih 30 dni",
    "No due date" : "Ni datuma preteka",
    "Clear filter" : "Počisti filter",
    "Hide archived cards" : "Skrij arhivirane naloge",
    "Show archived cards" : "Prikaži arhivirane naloge",
    "Toggle compact mode" : "Preklopi način prikaza",
    "Details" : "Podrobnosti",
    "Loading board" : "Poteka nalaganje zbirke",
    "Board not found" : "Zbirke ni mogoče najti",
    "Sharing" : "Souporaba",
    "Tags" : "Oznake",
    "Deleted items" : "Izbrisani predmeti",
    "Timeline" : "Časovnica",
    "Deleted lists" : "Izbrisani seznami",
    "Undo" : "Razveljavi",
    "Deleted cards" : "Izbrisane naloge",
    "Share board with a user, group or circle …" : "Souporaba z uporabniki, skupinami ali krogi ...",
    "Board owner" : "Lastnik zbirke",
    "(Group)" : "(Skupina)",
    "(Circle)" : "(Krog)",
    "Can edit" : "Lahko ureja",
    "Can share" : "Lahko omogoči souporabo",
    "Can manage" : "Lahko upravlja",
    "Delete" : "Izbriši",
    "Add a new list" : "Dodaj nov seznam",
    "Delete list" : "Izbriši seznam",
    "Add card" : "Dodaj nalogo",
    "Add a new card" : "Dodaj novo nalogo",
    "Edit" : "Uredi",
    "Add a new tag" : "Dodaj novo oznako",
    "title and color value must be provided" : "navedena morata biti podatka naslova in barve",
    "Title" : "Naslov",
    "Members" : "Člani",
    "Upload attachment" : "Pošlji prilogo",
    "Add this attachment" : "Dodaj prilogo",
    "Delete Attachment" : "Izbriši prilogo",
    "Restore Attachment" : "Obnovi prilogo",
    "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
    "Assign to users" : "Dodeli uporabnikom",
    "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom",
    "Assign a user to this card…" : "Dodeli uporabnika k nalogi ...",
    "Due date" : "Datum preteka",
    "Set a due date" : "Nastavi datum preteka",
    "Remove due date" : "Odstrani datum preteka",
    "Description" : "Opis",
    "(Unsaved)" : "(neshranjeno)",
    "(Saving…)" : "(shranjevanje ...)",
    "Formatting help" : "Pomoč pri oblikovanju",
    "Edit description" : "Uredi opis",
    "View description" : "Pokaži opis",
    "Add Attachment" : "Dodaj prilogo",
    "Attachments" : "Priloge",
    "Comments" : "Opombe",
    "Choose attachment" : "Izbor priloge",
    "Select Date" : "Izbor datuma",
    "Modified" : "Spremenjeno",
    "Created" : "Ustvarjeno",
    "No comments yet. Begin the discussion!" : "Ni še odzivov, bodite prvi!",
    "Save" : "Shrani",
    "The comment cannot be empty." : "Polje opombe ne sme biti prazno.",
    "The comment cannot be longer than 1000 characters." : "Opomba ne sme biti daljša od 1000 znakov.",
    "In reply to" : "V odgovor",
    "Reply" : "Odgovori",
    "Update" : "Posodobi",
    "(group)" : "(skupina)",
    "(circle)" : "(krog)",
    "Assign to me" : "Nalogo dodeli meni",
    "Unassign myself" : "Odstrani me z naloge",
    "Unarchive card" : "Povrni nalogo",
    "Archive card" : "Arhiviraj nalogo",
    "Delete card" : "Izbriši nalogo",
    "Move card" : "Premakni nalogo",
    "Move card to another board" : "Premakni nalogo v drugo zbirko",
    "Select a list" : "Izbor seznama",
    "seconds ago" : "pred nekaj sekundami",
    "All boards" : "Vse zbirke",
    "Archived boards" : "Arhivirane zbirke",
    "Shared with you" : "V souporabi z vami",
    "Limit deck usage of groups" : "Omeji uporabo zbirk na skupine",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo.",
    "Edit board" : "Uredi zbirko",
    "Clone board " : "Kloniraj zbirko",
    "Unarchive board " : "Povrni zbirko iz arhiva",
    "Archive board " : "Arhiviraj zbirko",
    "Delete board " : "Izbriši zbirko",
    "Board details" : "Podrobnosti zbirke",
    "Board {0} deleted" : "Zbirka {0} je izbrisana",
    "An error occurred" : "Prišlo je do napake.",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ali ste prepričani, da želite izbrisati zbirko »{title}«? S tem boste izbrisali tudi vse podatke zbirke.",
    "Delete the board?" : "Ali želite izbrisati zbirko?",
    "Today" : "Danes",
    "Tomorrow" : "Jutri",
    "This week" : "Ta teden",
    "Link to a board" : "Povezava do zbirke",
    "Link to a card" : "Povezava do naloge",
    "Something went wrong" : "Prišlo je do napake ...",
    "Maximum file size of {size} exceeded" : "Omejitev velikosti datoteke {size} je prekoračena."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
